package raptor.model;

import java.util.ArrayList;

public class Section
{
	private String name;
	private SpeedingTicketCollector collector;
	private double speedLimit;
	private double length;
	
	private ArrayList<Transit> inTransits = new ArrayList<Transit>();

	public Section(String name, double speedLimit, double length, SpeedingTicketCollector collector)
	{
		this.name = name;
		this.speedLimit = speedLimit;
		this.length = length;
		this.collector = collector;
	}
	
	public String getName()
	{
		return name;
	}
	
	public double getSpeedLimit()
	{
		return speedLimit;
	}
	
	public double getLength()
	{
		return length;
	}
	
	public void putTransit(Transit transit)
	{
		switch (transit.getGate())
		{
			case IN:
				manageInTransit(transit);
				break;
			case OUT:
				manageOutTransit(transit);
				break;
		}
	}

	private void manageOutTransit(Transit outTransit)
	{
		Transit inTransit = findInTransitFor(outTransit.getPlate());
		long millis = outTransit.getDate().getTime() - inTransit.getDate().getTime();
		double actualSpeed = getLength() / (millis / 3600000.0);
		if (actualSpeed > getSpeedLimit())
		{
			collector.add(new SpeedingTicket(getSpeedLimit(), actualSpeed, inTransit, outTransit));
		}
		inTransits.remove(inTransit);
	}

	private Transit findInTransitFor(String plate)
	{
		for (Transit inTransit : inTransits)
		{
			if (inTransit.getPlate().equals(plate))
			{
				return inTransit;
			}
		}
		throw new IllegalArgumentException("In transit not found");
	}

	private void manageInTransit(Transit inTransit)
	{
		if (!inTransit.getSectionName().equals(getName()))
			throw new IllegalArgumentException("!inTransit.getSection().equals(getName())");
		inTransits.add(inTransit);
	}
	
	@Override
	public String toString()
	{
		return name + " - Limit " + speedLimit + "km/h, Length " + length + "km";
	}
}
