package raptor.model;

import java.text.NumberFormat;
import java.util.Date;
import java.util.Locale;

public class SpeedingTicket
{	
	private double speedLimit;
	private double actualSpeed;
	private Transit inTransit;
	private Transit outTransit;
	private double speedDifference;
	private Fine fine;

	public SpeedingTicket(double speedLimit, double actualSpeed, Transit inTransit, Transit outTransit)
	{
		this.speedLimit = speedLimit;
		this.actualSpeed = actualSpeed;
		this.inTransit = inTransit;
		this.outTransit = outTransit;
		this.speedDifference = Math.abs(this.speedLimit - this.actualSpeed);
		this.fine = (speedDifference<=10 ? Fine.LessThan10 : speedDifference<=40 ? Fine.LessThan40 :
				     speedDifference<=60 ? Fine.LessThan60 : Fine.Beyond60);
	}
	
	public Transit getInTransit()
	{
		return inTransit;
	}
	
	public Transit getOutTransit()
	{
		return outTransit;
	}
	
	public String getSectionName()
	{
		return outTransit.getSectionName();
	}
	
	public Date getDate()
	{
		return outTransit.getDate();
	}
	
	public String getPlate()
	{
		return outTransit.getPlate();
	}
	
	public double getSpeedLimit()
	{
		return speedLimit;
	}
	
	public double getActualSpeed()
	{
		return actualSpeed;
	}
	
	public Fine getFine()
	{
		return fine;
	}
	
	public String toString()
	{
		NumberFormat format = NumberFormat.getInstance(Locale.ITALY);
		format.setMaximumFractionDigits(0);
		return "Violazione di " + format.format(speedDifference) + " km/h (limite " + format.format(speedLimit) +
		", velocit registrata " + format.format(actualSpeed) + ") per il veicolo " +  getPlate()
				+ " -- MULTA  " + getFine().getValue();
	}
}
