package raptor.persistence;

import java.io.BufferedReader;
import java.io.IOException;
import java.io.Reader;
import java.util.ArrayList;
import java.util.List;

import raptor.model.Section;
import raptor.model.SpeedingTicketCollector;

public class MySectionReader implements SectionReader
{
	private static final String Separator = " ";

	@Override
	public List<Section> readSections(SpeedingTicketCollector collector, Reader reader) throws IOException, MalformedFileException
	{
		ArrayList<Section> sections = new ArrayList<Section>();
		BufferedReader bufferedReader = new BufferedReader(reader);
		String line;
		while ((line = bufferedReader.readLine()) != null && !line.trim().isEmpty())
		{
			String[] tokens = line.split(Separator);
			if (tokens.length != 3)
				throw new MalformedFileException("tokens.length != 3");
						
			int speedLimit;
			double length;
			try
			{
				speedLimit = Integer.parseInt(tokens[2]);
				length = Double.parseDouble(tokens[1]);
			}
			catch (NumberFormatException e)
			{
				throw new MalformedFileException(e);
			}
			
			Section section = new Section(tokens[0], speedLimit, length, collector); 
			sections.add(section);
		}
		return sections;
	}

}
