package raptor.persistence;

import java.io.BufferedReader;
import java.io.IOException;
import java.io.Reader;
import java.text.DateFormat;
import java.text.ParseException;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;
import java.util.Locale;

import raptor.model.Gate;
import raptor.model.Transit;

public class MyTransitReader implements TransitReader
{
	private static final String Separator = " ";

	@Override
	public List<Transit> readTransits(Reader reader) throws IOException, MalformedFileException
	{
		ArrayList<Transit> transits = new ArrayList<Transit>();
		DateFormat dateTimeFormat = DateFormat.getDateTimeInstance(DateFormat.SHORT, DateFormat.MEDIUM, Locale.ITALY);
		BufferedReader bufferedReader = new BufferedReader(reader);
		String line;
		while ((line = bufferedReader.readLine()) != null && !line.trim().isEmpty())
		{
			String[] tokens = line.split(Separator);
			if (tokens.length != 5)
				throw new MalformedFileException("tokens.length != 5");

			Gate gate = getGate(tokens[1]);

			String dateTime = tokens[3] + " " + tokens[4];
			Date date = getDate(dateTimeFormat, dateTime);

			Transit transit = new Transit(tokens[0], gate, date, tokens[2]);
			transits.add(transit);
		}
		return transits;
	}

	private Date getDate(DateFormat dateTimeFormat, String dateTime) throws MalformedFileException
	{
		try
		{
			return dateTimeFormat.parse(dateTime);
		}
		catch (ParseException e)
		{
			throw new MalformedFileException(e);
		}
	}

	private Gate getGate(String value) throws MalformedFileException
	{
		try
		{
			return Gate.valueOf(value);
		}
		catch (Exception e)
		{
			throw new MalformedFileException("gate == null");
		}
	}

}
